"""
COMMAND-LINE SPECIFIC STUFF
=============================================================================

"""

import markdown
import optparse
import sys

import logging
from logging import DEBUG, INFO, CRITICAL

logger =  logging.getLogger('MARKDOWN')

RESULT_HEADER = '''<html lang="zh_CN">
        <head>
        <meta charset="UTF-8">
        <style id="system" type="text/css">
        h1,h2,h3,h4,h5,h6,p,blockquote {    margin: 0;    padding: 0;}
        body {    font-family: "Helvetica Neue", Helvetica, "Hiragino Sans GB", Arial, sans-serif; 
        font-size: 13px;    line-height: 18px;    color: #737373;    margin: 10px 13px 10px 13px;}
        a {    color: #0069d6;}
        a:hover {    color: #0050a3;    text-decoration: none;}
        a img {    border: none;}
        p {    margin-bottom: 9px;}
        h1,h2,h3,h4,h5,h6 {    color: #404040;    line-height: 36px;}
        h1 {    margin-bottom: 18px;    font-size: 30px;}
        h2 {    font-size: 24px;}
        h3 {    font-size: 18px;}
        h4 {    font-size: 16px;}
        h5 {    font-size: 14px;}
        h6 {    font-size: 13px;}
        hr {    margin: 0 0 19px;    border: 0;    border-bottom: 1px solid #ccc;}
        blockquote {    padding: 13px 13px 21px 15px;    margin-bottom: 18px;
        font-family:georgia,serif;    font-style: italic;}
        blockquote:before {    content:"Q";    font-size:40px;    margin-left:-10px;
        font-family:georgia,serif;    color:#eee;}
        blockquote p {    font-size: 14px;    font-weight: 300;    line-height: 18px;
        margin-bottom: 0;    font-style: italic;}
        code, pre {    font-family: Monaco, Andale Mono, Courier New, monospace;}
        code {    background-color: #fee9cc;    color: rgba(0, 0, 0, 0.75);    padding: 1px 3px;
        font-size: 12px;    -webkit-border-radius: 3px;    -moz-border-radius: 3px;    border-radius: 3px;}
        pre {    display: block;    padding: 14px;    margin: 0 0 18px;    line-height: 16px;
        font-size: 11px;    border: 1px solid #d9d9d9;    white-space: pre-wrap;    word-wrap: break-word;}
        pre code {    background-color: #fff;    color:#737373;    font-size: 11px;    padding: 0;}
        @media screen and (min-width: 768px) {    body {        width: 748px;        margin:10px auto;    }}
        </style>
        </head>
        <body marginheight="0">
        
        '''

RESULT_FOOTER = '''

        </body></html>'''

def parse_options():
    """
    Define and parse `optparse` options for command-line usage.
    """
    usage = """%prog [options] [INPUTFILE]
       (STDIN is assumed if no INPUTFILE is given)"""
    desc = "A Python implementation of John Gruber's Markdown. " \
           "http://packages.python.org/Markdown/"
    ver = "%%prog %s" % '2.3.1'
    
    parser = optparse.OptionParser(usage=usage, description=desc, version=ver)
    parser.add_option("-e", "--encoding", dest="encoding",
                      help="Encoding for input and output files.",)
    parser.add_option("-q", "--quiet", default = CRITICAL,
                      action="store_const", const=CRITICAL+10, dest="verbose",
                      help="Suppress all warnings.")
    parser.add_option("-v", "--verbose",
                      action="store_const", const=INFO, dest="verbose",
                      help="Print all warnings.")
    parser.add_option("-s", "--safe", dest="safe", default=False,
                      metavar="SAFE_MODE",
                      help="'replace', 'remove' or 'escape' HTML tags in input")
    parser.add_option("-o", "--output_format", dest="output_format", 
                      default='xhtml1', metavar="OUTPUT_FORMAT",
                      help="'xhtml1' (default), 'html4' or 'html5'.")
    parser.add_option("--noisy",
                      action="store_const", const=DEBUG, dest="verbose",
                      help="Print debug messages.")
    parser.add_option("-x", "--extension", action="append", dest="extensions",
                      help = "Load extension EXTENSION.", metavar="EXTENSION")
    parser.add_option("-n", "--no_lazy_ol", dest="lazy_ol", 
                      action='store_false', default=True,
                      help="Observe number of first item of ordered lists.")

    (options, args) = parser.parse_args()

    if len(args) == 0:
        input_file = None
    else:
        input_file = args[0]

    if not options.extensions:
        options.extensions = []

    return {'input': input_file,
            'output': None, # stdout
            'safe_mode': options.safe,
            'extensions': options.extensions,
            'encoding': options.encoding,
            'output_format': options.output_format,
            'lazy_ol': options.lazy_ol}, options.verbose

if __name__ == '__main__':
    """
    Run Markdown from the command line.
    Python 2.7 & 3.x do: `python -m markdown [options] [args]`.
    """
    options, logging_level = parse_options()
    if not options:
        sys.exit(2)
    logger.setLevel(logging_level)
    logger.addHandler(logging.StreamHandler())

    print(RESULT_HEADER)
    markdown.markdownFromFile(**options)
    print(RESULT_FOOTER)

